@@ -2,7 +2,7 @@
 
    Methods for reading jpeg images
 
-   Copyright (C) 2003-2010 Free Software Foundation, Inc.
+   Copyright (C) 2003-2014 Free Software Foundation, Inc.
    
    Written by:  Stefan Kleine Stegemann <stefan@wms-network.de>
    Date: Nov 2003
@@ -600,11 +600,12 @@ static void gs_jpeg_memory_dest_destroy (j_compress_ptr cinfo)
   jpeg_set_defaults (&cinfo);
 
   // set quality
-  
+  // we expect a value between 0..1, 0 being lowest, 1 highest quality
+
   qualityNumber = [properties objectForKey: NSImageCompressionFactor];
   if (qualityNumber != nil)
     {
-      quality = (int) ((1-[qualityNumber floatValue] / 255.0) * 100.0);
+      quality = (int) ([qualityNumber floatValue] * 100.0);
     }
 
   // set progressive mode
