@@ -1780,6 +1780,53 @@ static NSColor *dtxtCol;
   return NO; // Otherwise return NO
 }
 
+- (NSUInteger) hitTestForEvent: (NSEvent*)event
+                       inRect: (NSRect)cellFrame
+                       ofView: (NSView*)controlView
+{
+  if (_cell.type == NSImageCellType)
+    {
+      if ((_cell_image != nil) && 
+          NSMouseInRect([controlView convertPoint: [event locationInWindow]
+                                         fromView: nil],
+                        [self imageRectForBounds: [controlView bounds]],
+                        [controlView isFlipped]))
+        {
+          return NSCellHitContentArea;
+        }
+      else
+        {
+          return NSCellHitNone;
+        }
+    }
+  else if (_cell.type == NSTextCellType)
+    {
+      if (_contents == nil)
+        {
+          return NSCellHitNone;
+        }
+      else if (_cell.is_disabled == NO)
+        {
+          return NSCellHitContentArea | NSCellHitEditableTextArea;
+        }
+      else
+        {
+          return NSCellHitContentArea;
+        }
+    }
+  else
+    {
+      if (_cell.is_disabled == NO)
+        {
+          return NSCellHitContentArea | NSCellHitTrackableArea;
+        }
+      else
+        {
+          return NSCellHitContentArea;
+        }
+    }
+}
+
 /** <p>TODO</p>
  */
 - (void) resetCursorRect: (NSRect)cellFrame inView: (NSView*)controlView
@@ -2349,7 +2396,7 @@ static NSColor *dtxtCol;
   _menu = TEST_RETAIN (_menu);
   _cell_image = TEST_RETAIN (_cell_image);
   _formatter = TEST_RETAIN (_formatter);
-  _formatter = TEST_RETAIN (_represented_object);
+  _represented_object = TEST_RETAIN (_represented_object);
 
   return c;
 }
@@ -2363,21 +2410,9 @@ static NSColor *dtxtCol;
     {
       unsigned long cFlags = 0;
       unsigned int cFlags2 = 0;
-      id contents;
+      id contents = _contents;
 
       // encode contents
-      if (_cell.type == NSTextCellType)
-        {
-          contents = _contents;
-        }
-      else if (_cell.type == NSImageCellType)
-        {
-          contents = _cell_image;
-        }
-      else
-        {
-          contents = [self objectValue];
-        }
       [aCoder encodeObject: contents forKey: @"NSContents"];
 
       // flags
