@@ -355,6 +355,12 @@
         }
       [responder setNextResponder: [self nextResponder]];
       [_window setWindowController: nil];
+
+      // Remove the delegate as well if set to the owner in the NIB file
+      if ([_window delegate] == _owner)
+        {
+          [_window setDelegate: nil];
+        }
     }
 
   ASSIGN(_window, aWindow);
